rf.null_test: (Non)Parametric Hypothesis testing for Leave-One-Out Models

View source: R/rf.null_test.R

rf.null_testR Documentation

(Non)Parametric Hypothesis testing for Leave-One-Out Models

Description

Function to test a generated Leave-One-Out model against the bootstrapped estimations for hypothesis testing. Requires a LOO model and a bootstrapped model built using the randomForestLOO pacakge.

Usage

rf.null_test(loo_input, bootstrap_error, model_type, method)

Arguments

loo_input

A LOO model estimated using the randomForestLOO package.

bootstrap_error

Bootstrap error model derived from the randomForestLOO package.

xmodel_type

String. Can be "norm" or "actual". "actual" returns results for the null test using the full distribution of the errors estimated from the bootstrapped models. "norm" returns results of the null test based on the overall mean and standard deviations under assumptions of normality. "actual" recommended.

method

String. Indicates if the model used is a "LOSO" or "LOBO" model.

Value

p_val

List of p-values obtained for each participant.

stouffer

A combined p-value across all participants using Stouffer's Method.

Author(s)

Rayyan Tutunji | rayyan.tutunji[at]donders.ru.nl

References

Using wearable biosensors and ecological momentary assessments for the detection of prolonged stress in real life Rayyan Tutunji, Nikos Kogias, Bob Kapteijns, Martin Krentz, Florian Krause, Eliana Vassena, Erno Hermans bioRxiv 2021.06.29.450360; doi: https://doi.org/10.1101/2021.06.29.450360


raytut/randomForestLOO documentation built on May 30, 2022, 8:47 p.m.