| rf.null_test | R Documentation |
Function to test a generated Leave-One-Out model against the bootstrapped estimations for hypothesis testing. Requires a LOO model and a bootstrapped model built using the randomForestLOO pacakge.
rf.null_test(loo_input, bootstrap_error, model_type, method)
loo_input |
A LOO model estimated using the randomForestLOO package. |
bootstrap_error |
Bootstrap error model derived from the randomForestLOO package. |
xmodel_type |
String. Can be "norm" or "actual". "actual" returns results for the null test using the full distribution of the errors estimated from the bootstrapped models. "norm" returns results of the null test based on the overall mean and standard deviations under assumptions of normality. "actual" recommended. |
method |
String. Indicates if the model used is a "LOSO" or "LOBO" model. |
p_val |
List of p-values obtained for each participant. |
stouffer |
A combined p-value across all participants using Stouffer's Method. |
Rayyan Tutunji | rayyan.tutunji[at]donders.ru.nl
Using wearable biosensors and ecological momentary assessments for the detection of prolonged stress in real life Rayyan Tutunji, Nikos Kogias, Bob Kapteijns, Martin Krentz, Florian Krause, Eliana Vassena, Erno Hermans bioRxiv 2021.06.29.450360; doi: https://doi.org/10.1101/2021.06.29.450360
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.